pandas.CategoricalIndex
=======================

.. currentmodule:: pandas

.. autoclass:: CategoricalIndex

   


..
   HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
   .. autosummary::
      :toctree:
      
      CategoricalIndex.add_categories
      CategoricalIndex.all
      CategoricalIndex.any
      CategoricalIndex.append
      CategoricalIndex.argmax
      CategoricalIndex.argmin
      CategoricalIndex.argsort
      CategoricalIndex.as_ordered
      CategoricalIndex.as_unordered
      CategoricalIndex.asof
      CategoricalIndex.asof_locs
      CategoricalIndex.astype
      CategoricalIndex.copy
      CategoricalIndex.delete
      CategoricalIndex.difference
      CategoricalIndex.drop
      CategoricalIndex.drop_duplicates
      CategoricalIndex.dropna
      CategoricalIndex.duplicated
      CategoricalIndex.equals
      CategoricalIndex.factorize
      CategoricalIndex.fillna
      CategoricalIndex.format
      CategoricalIndex.get_duplicates
      CategoricalIndex.get_indexer
      CategoricalIndex.get_indexer_for
      CategoricalIndex.get_indexer_non_unique
      CategoricalIndex.get_level_values
      CategoricalIndex.get_loc
      CategoricalIndex.get_slice_bound
      CategoricalIndex.get_value
      CategoricalIndex.get_values
      CategoricalIndex.groupby
      CategoricalIndex.holds_integer
      CategoricalIndex.identical
      CategoricalIndex.insert
      CategoricalIndex.intersection
      CategoricalIndex.is_
      CategoricalIndex.is_boolean
      CategoricalIndex.is_categorical
      CategoricalIndex.is_floating
      CategoricalIndex.is_integer
      CategoricalIndex.is_lexsorted_for_tuple
      CategoricalIndex.is_mixed
      CategoricalIndex.is_numeric
      CategoricalIndex.is_object
      CategoricalIndex.is_type_compatible
      CategoricalIndex.isin
      CategoricalIndex.item
      CategoricalIndex.join
      CategoricalIndex.map
      CategoricalIndex.max
      CategoricalIndex.memory_usage
      CategoricalIndex.min
      CategoricalIndex.nunique
      CategoricalIndex.order
      CategoricalIndex.putmask
      CategoricalIndex.ravel
      CategoricalIndex.reindex
      CategoricalIndex.remove_categories
      CategoricalIndex.remove_unused_categories
      CategoricalIndex.rename
      CategoricalIndex.rename_categories
      CategoricalIndex.reorder_categories
      CategoricalIndex.repeat
      CategoricalIndex.reshape
      CategoricalIndex.searchsorted
      CategoricalIndex.set_categories
      CategoricalIndex.set_names
      CategoricalIndex.set_value
      CategoricalIndex.shift
      CategoricalIndex.slice_indexer
      CategoricalIndex.slice_locs
      CategoricalIndex.sort
      CategoricalIndex.sort_values
      CategoricalIndex.sortlevel
      CategoricalIndex.summary
      CategoricalIndex.sym_diff
      CategoricalIndex.symmetric_difference
      CategoricalIndex.take
      CategoricalIndex.to_datetime
      CategoricalIndex.to_native_types
      CategoricalIndex.to_series
      CategoricalIndex.tolist
      CategoricalIndex.transpose
      CategoricalIndex.union
      CategoricalIndex.unique
      CategoricalIndex.value_counts
      CategoricalIndex.view
      CategoricalIndex.where




   


..
   HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
   .. autosummary::
      :toctree:
      
      CategoricalIndex.T
      CategoricalIndex.asi8
      CategoricalIndex.base
      CategoricalIndex.categories
      CategoricalIndex.codes
      CategoricalIndex.data
      CategoricalIndex.dtype
      CategoricalIndex.dtype_str
      CategoricalIndex.flags
      CategoricalIndex.has_duplicates
      CategoricalIndex.hasnans
      CategoricalIndex.inferred_type
      CategoricalIndex.is_all_dates
      CategoricalIndex.is_monotonic
      CategoricalIndex.is_monotonic_decreasing
      CategoricalIndex.is_monotonic_increasing
      CategoricalIndex.is_unique
      CategoricalIndex.itemsize
      CategoricalIndex.name
      CategoricalIndex.names
      CategoricalIndex.nbytes
      CategoricalIndex.ndim
      CategoricalIndex.nlevels
      CategoricalIndex.ordered
      CategoricalIndex.shape
      CategoricalIndex.size
      CategoricalIndex.strides
      CategoricalIndex.values


